@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Glorified metronome
 
-our $VERSION = '0.4007';
+our $VERSION = '0.4008';
 
 use strictures 2;
 use Data::Dumper::Compact qw(ddc);
@@ -139,7 +139,11 @@ has dotted_onetwentyeighth        => (is => 'ro', default => sub { 'dzn' });
 has double_dotted_onetwentyeighth => (is => 'ro', default => sub { 'ddzn' });
 
 
-sub note { return shift->score->n(@_) }
+sub note {
+    my ($self, @spec) = @_;
+    $self->counter( $self->counter + dura_size($spec[0]) );
+    return $self->score->n(@spec);
+}
 
 
 sub accent_note {
@@ -152,7 +156,11 @@ sub accent_note {
 }
 
 
-sub rest { return shift->score->r(@_) }
+sub rest {
+    my ($self, @spec) = @_;
+    $self->counter( $self->counter + dura_size($spec[0]) );
+    return $self->score->r(@spec);
+}
 
 
 sub count_in {
@@ -591,7 +599,7 @@ MIDI::Drummer::Tiny - Glorified metronome
 
 =head1 VERSION
 
-version 0.4007
+version 0.4008
 
 =head1 SYNOPSIS
 
@@ -628,6 +636,8 @@ version 0.4007
  $d->note($d->quarter, $d->open_hh, $_ % 2 ? $d->kick : $d->snare)
     for 1 .. $d->beats * $d->bars;
 
+ print 'Count: ', $d->counter, "\n";
+
  # Same but with beat-strings:
  $d->sync_patterns(
     $d->open_hh => [ ('1111') x $d->bars ],
@@ -723,6 +733,9 @@ Default: C<4>
 Beat counter of durations, where a quarter-note is equal to 1. An
 eighth-note is 0.5, etc.
 
+This is automatically accumulated each time a C<rest> or C<note> is
+added to the score.
+
 =head1 KIT
 
 =over 4
@@ -797,6 +810,8 @@ Add notes to the score.
 
 This method takes the same arguments as L<MIDI::Simple/"Parameters for n/r/noop">.
 
+It also keeps track of the beat count with the C<counter> attribute.
+
 =head2 accent_note
 
   $d->accent_note($accent_value, $d->sixteenth, $d->snare);
@@ -815,6 +830,8 @@ Add a rest to the score.
 
 This method takes the same arguments as L<MIDI::Simple/"Parameters for n/r/noop">.
 
+It also keeps track of the beat count with the C<counter> attribute.
+
 =head2 count_in
 
  $d->count_in;
@@ -904,7 +921,7 @@ If not provided the B<snare> is used for the B<grace> and B<patch>
 patches.  Also, 1/2 of the score volume is used for the B<accent>
 if that is not given.
 
-If the B<grace> note is riven as a literal C<'r'>, rest instead adding
+If the B<grace> note is given as a literal C<'r'>, rest instead adding
 a note to the score.
 
 =head2 roll
